@@ -3,9 +3,10 @@
 html_dependency_virtualselect <- function() {
   htmlDependency(
     name = "virtual-select",
-    version = "1.0.24",
+    version = "1.0.41",
     src = c(file = system.file("packer", package = "shinyWidgets")),
-    script = "virtual-select.js"
+    script = "virtual-select.js",
+    all_files = FALSE
   )
 }
 
@@ -93,6 +94,7 @@ prepare_choices <- function(.data,
 #' @param ... Other arguments passed to JavaScript method, see
 #'  [virtual-select documentation](https://sa-si-dev.github.io/virtual-select/#/properties) for a full list of options.
 #' @param stateInput Activate or deactivate the special input value `input$<inputId>_open` to know if the menu is opened or not, see details.
+#' @param updateOn When to update the input value server-side : on each changes or when the menu is closed.
 #' @param html Allow usage of HTML in choices.
 #' @param inline Display inline with label or not.
 #'
@@ -136,10 +138,12 @@ virtualSelectInput <- function(inputId,
                                disabled = FALSE,
                                ...,
                                stateInput = TRUE,
+                               updateOn = c("change", "close"),
                                html = FALSE,
                                inline = FALSE,
                                width = NULL) {
   selected <- restoreInput(id = inputId, default = selected)
+  updateOn <- match.arg(updateOn)
   choices <- process_choices(choices)
   data <- list(
     stateInput = stateInput,
@@ -185,6 +189,7 @@ virtualSelectInput <- function(inputId,
       id = inputId,
       class = "virtual-select",
       style = div_css,
+      `data-update` = updateOn,
       tags$script(
         type = "application/json",
         `data-for` = inputId,
@@ -207,6 +212,7 @@ virtualSelectInput <- function(inputId,
 #' @inheritParams shiny::updateSelectInput
 #' @param disable Disable (`TRUE`) or enable (`FALSE`) the select menu.
 #' @param disabledChoices List of disabled option's values.
+#' @param open Open (`TRUE`) or close (`FALSE`) the dropdown.
 #'
 #' @return No value.
 #'
@@ -224,6 +230,7 @@ updateVirtualSelect <- function(inputId,
                                 selected = NULL,
                                 disable = NULL,
                                 disabledChoices = NULL,
+                                open = NULL,
                                 session = shiny::getDefaultReactiveDomain()) {
   if (!is.null(label))
     label <- doRenderTags(label)
@@ -236,7 +243,8 @@ updateVirtualSelect <- function(inputId,
     options = choices,
     value = selected,
     disable = disable,
-    disabledChoices = list1(disabledChoices)
+    disabledChoices = list1(disabledChoices),
+    open = open
   ))
   session$sendInputMessage(inputId, message)
 }
